documentFactory.OaiDocumentStream

|  | ## Cheshire3 Object Model: Class OaiDocumentStream

Module documentFactory :: Class OaiDocumentStream

## Class OaiDocumentStream
source code

Object Tree:

    BaseDocumentStream --+
                         |
    MultipleDocumentStream --+
                             |
            HttpDocumentStream --+
                                 |
                                OaiDocumentStream

Instance Methods

open_stream(self, stream)
__init__(self, session, stream, format, schema=None, codec=None, factory=None)
find_documents(self, session, cache=0)
_listIdentifiers(self)
_getRecord(self)
Inherited from `HttpDocumentStream` (private): `_fetchName`, `_fetchStream`, `_processFile` Inherited from `MultipleDocumentStream` (private): `_processFiles` Inherited from `BaseDocumentStream`: `fetch_document`

Class Variables

Inherited from `BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`

Method Details

### open_stream(self, stream) | source code
Overrides: BaseDocumentStream.open_stream

### __init__(self, session, stream, format, schema=None, codec=None, factory=None) (Constructor) | source code
Overrides: HttpDocumentStream.__init__

### find_documents(self, session, cache=0) | source code
Overrides: HttpDocumentStream.find_documents

### _listIdentifiers(self) | source code

### _getRecord(self) | source code